RegisterAsyncFactory class
Annotation to mark a class for automatic async factory registration in GetIt.
When applied to a class, it will be registered as an async factory in GetIt, meaning an async method will be called to create new instances.
Example:
@RegisterAsyncFactory()
class MyService {
// This class will be registered as an async factory
}
Constructors
- RegisterAsyncFactory()
-
Creates an async factory registration annotation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited