RegisterAsyncLazySingleton class
Annotation to mark a class for automatic async lazy singleton registration in GetIt.
When applied to a class, it will be registered as an async lazy singleton in GetIt, meaning an async method will be called to create the instance when first requested.
Example:
@RegisterAsyncLazySingleton()
class MyService {
// This class will be registered as an async lazy singleton
}
Constructors
- RegisterAsyncLazySingleton()
-
Creates an async lazy singleton registration annotation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited