SourceDirectoryBuilder class

Custom builder that generates individual .g.dart files for each service.

This approach generates separate files for each service to avoid conflicts.

Constructors

SourceDirectoryBuilder(List<Generator> _generators)

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited