RegisterAsyncSingleton class

Annotation to mark a class for automatic async singleton registration in GetIt.

When applied to a class, it will be registered as an async singleton in GetIt, meaning an async method will be called to create the instance once.

Example:

@RegisterAsyncSingleton()
class MyService {
  // This class will be registered as an async singleton
}

Constructors

RegisterAsyncSingleton()
Creates an async singleton registration annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited