generateForAnnotatedElement method
- Element element,
- ConstantReader annotation,
- BuildStep buildStep
Implement to return source code to generate for element.
This method is invoked based on finding elements annotated with an
instance of T. The annotation is provided as a ConstantReader.
Supported return values include a single String or multiple String instances within an Iterable or Stream. It is also valid to return a Future of String, Iterable, or Stream. When multiple values are returned through an iterable or stream they will be deduplicated. Typically each value will be an independent unit of code and the deduplication prevents re-defining the same member multiple times. For example if multiple annotated elements may need a specific utility method available it can be output for each one, and the single deduplicated definition can be shared.
Implementations should return null when no content is generated. Empty
or whitespace-only String instances are also ignored.
Implementation
@override
String generateForAnnotatedElement(
Element element,
ConstantReader annotation,
BuildStep buildStep,
) {
if (element is! ClassElement) {
throw InvalidGenerationSourceError(
'Dependency injection annotations can only be applied to classes',
element: element,
);
}
final String? className = element.name;
// Get the annotation type from the element's metadata
final String annotationName = _getAnnotationName(element, annotation);
// Get registration type from annotation
final RegisterAs registrationType =
_getRegistrationTypeFromAnnotation(annotationName);
final bool isAsync = _isAsyncAnnotation(annotationName);
// Auto-detect constructor parameters
final _ConstructorInfo constructorInfo = _getConstructorInfo(element);
final String methodName = 'get$className';
final String registrationTypeEnum =
_getRegistrationTypeEnum(registrationType);
if (isAsync) {
return '''
Future<$className> $methodName() async {
return await GetIt.instance.getOrRegisterAsync<$className>(
() async => $className(${constructorInfo.constructorCall}), $registrationTypeEnum);
}
''';
} else {
return '''
$className $methodName() {
return GetIt.instance.getOrRegister<$className>(
() => $className(${constructorInfo.constructorCall}), $registrationTypeEnum);
}
''';
}
}